//package gliparameterizer;

/**
 * A single GLI light ray.
 * <p>Copyright: Copyright (c) 2004 Charles D. Canham</p>
 * <p>Company: Institute of Ecosystem Studies</p>
 * @author Lora E. Murphy
 * @version 1.0
 */

class GLIRay {

  /**Height of the ray's origin above the ground, in m*/
  public double m_fHeight;

  /**X coordinate (E-W), in m*/
  public double m_fX;

  /**Y coordinate (N-S), in m*/
  public double m_fY;

  /**Azimuth direction, in radians (converted from degrees in constructor)*/
  public double m_fAzimuth;

  /**Altitude of ray, in radians (converted from degrees in constructor)*/
  public double m_fAltitude;

  /**Subquad.  Not used in code, just captured to write to output file*/
  public String m_sSubquad;

  /**Light.  Not used in code, just captured to write to output file*/
  public String m_sLight;

  /**
   * Constructor.
   * @param fX double X coordinate - E-W distance in m.
   * @param fY double Y coordinate - N-S distance in m.
   * @param fHeight double Height above ground, in m.
   * @param fAzimuth double Azimuth direction, in degrees.
   * @param fAltitude double Altitude direction, in degrees.
   * @param sSubquad Subquad value.
   * @param sLight Light value.
   * @throws Exception if:
   * <ul>
   * <li>X or Y coordinate is less than 0</li>
   * <li>Azimuth or altitude is less than 0</li>
   * <li>Height is less than 0</li>
   * </ul>
   */
  public GLIRay(double fX, double fY, double fHeight, double fAzimuth, double
                fAltitude, String sSubquad, String sLight) throws Exception {

    if (fX < 0 || fY < 0) {
      throw new Exception("Both X and Y for GLI rays must be positive numbers.");
    }

    if (fHeight < 0) {
      throw new Exception("Height of ray origin must be a positive number.");
    }

    if (fAzimuth < 0 || fAltitude < 0) {
      throw new Exception("Both azimuth and altitude must be positive numbers.");
    }

    m_fX = fX;
    m_fY = fY;
    m_fHeight = fHeight;
    m_fAzimuth = fAzimuth * java.lang.Math.PI / 180.0;
    m_fAltitude = fAltitude * java.lang.Math.PI / 180.0;
    m_sSubquad = sSubquad;
    m_sLight = sLight;
  }

}
