//package gliparameterizer;

import java.io.FileReader;
import java.util.Vector;

/**
 * This provides common file-reading functions for reading tab-delimited files.
 * <p>Copyright: Copyright (c) Charles D. Canham 2003</p>
 * <p>Company: Institute of Ecosystem Studies</p>
 * @author Lora E. Murphy
 * @version 1.0
 */

public class ModelFileFunctions {
  /**
   * Advances a file stream to the beginning of the next line.
   *
   * @param in The file stream to advance.
   * @throws Exception if the file terminates unexpectedly before reaching the
   * end of the line.
   * @throws java.io.IOException if there is a problem reading the file.
   */
  static public void SkipLine(FileReader in) throws Exception, java.io.IOException {
    int iTestCh;

      //Get the first character - if it's unexpectedly end of file throw
      //an exception
      iTestCh = in.read();
      if ( -1 == iTestCh) {
        throw new Exception ("This file terminated unexpectedly.");
      }
      while (iTestCh != '\n' && iTestCh != -1) {
        iTestCh = in.read();
      }
  }

  /**
   * Reads a line from a tab-delimited text file.  Each cell in the line is
   * placed in a separate bucket of a Vector.  The file stream is then advanced
   * to the beginning of the next line.
   * @param in The file stream to read from.
   * @return The vector representing the file line.
   * @throws java.io.IOException - passthru from FileReader
   */

  static public Vector ReadLine(FileReader in) throws java.io.IOException {
    Vector p_oLine = new Vector(0);
    String sData;
    int iTestCh;

    iTestCh = in.read();
    while (iTestCh != '\n' && iTestCh != -1) {

      sData = "";
      while (iTestCh != '\t' && iTestCh != '\r' && iTestCh != '\n' && iTestCh != -1) {
        sData = sData.concat(String.valueOf( (char) iTestCh));
        iTestCh = in.read();
      }

      //Throw away extra tab characters
      while (iTestCh == '\t') {
        iTestCh = in.read();
      }

      if (sData.length() > 0) {
        p_oLine.add(sData.trim());
      }

      if ('\r' == iTestCh) { //advance to '\n'
        iTestCh = in.read();
      }
    }

    return p_oLine;
  }

}
