//package gliparameterizer;

/**
 * Class for a single tree's data.
 * <p>Copyright: Copyright (c) 2004 Charles D. Canham</p>
 * <p>Company: Institute of Ecosystem Studies</p>
 * @author Lora E. Murphy
 * @version 1.0
 */
class Tree {
  /**Name of species*/
  public String m_sSpecies;

  /**DBH, in cm.*/
  public double m_fDBH;

  /**X coordinate (E-W), in m*/
  public double m_fX;

  /**Y coordinate (N-S), in m*/
  public double m_fY;

  /**Height, in m.  Calculated from DBH.*/
  public double m_fHeight;

  /**Height of bottom of canopy, in m.  Calculated from Height.*/
  public double m_fCanopyBottomHeight;

  /**Canopy radius, in m.  Calculated from DBH.*/
  public double m_fCanopyRadius;

  /**Tag number.  Unused in the code.  It just gets spit back out in the
   * reporting.*/
  public int m_iTag;

  /**Damage code.  Unused in the code.  It just gets spit back out in the
   * reporting.*/
  public byte m_iDamageCode;

  /**
   * Constructor.
   * @param sSpecies String Name of species.
   * @param fX X coordinate
   * @param fY Y coordinate
   * @param fDBH double DBH value.
   * @param iTag int Tag number.
   * @param iDamageCode byte Damage code.
   * @param oAllTrees Object for getting allometry data.
   * @throws Exception if the DBH is less than or equal to 0.
   */
  public Tree(String sSpecies, double fX, double fY, double fDBH, int iTag, byte iDamageCode,
              AllTrees oAllTrees) throws Exception {

    if (fDBH <= 0) {
      throw new Exception("DBH must be greater than 0.");
    }

    m_sSpecies = sSpecies;
    m_fX = fX;
    m_fY = fY;
    m_fDBH = fDBH;
    m_iTag = iTag;
    m_iDamageCode = iDamageCode;

    //Calculate the height - with one-off exception for Puerto Rico
    if (sSpecies.equals("PREMON")) {
      m_fHeight = (double) 1.35 +
          (double) ( ( 20.0 - 1.35) *
                   (1.0 - java.lang.Math.exp( -1.0 *
                                             oAllTrees.GetHeightConstant(
          sSpecies) * fDBH)));

    } else {

    	// new implementation for Fred
    	m_fHeight = oAllTrees.GetHeightIntercept(sSpecies) + oAllTrees.GetHeightSlope(sSpecies) * fDBH;

    	// original implementation
//      m_fHeight = (double) 1.35 +
//      (double) ( (oAllTrees.GetMaxHeight(sSpecies) - 1.35) *
//               (1.0 - java.lang.Math.exp( -1.0 *
//                                         oAllTrees.GetHeightConstant(
//      sSpecies) * fDBH)));

    }

    //Calculate the canopy radius
    m_fCanopyRadius = java.lang.Math.pow(fDBH, oAllTrees.GetCanopyRadiusExponent(sSpecies)) * oAllTrees.GetCanopyRadiusCoefficient(sSpecies);

    //Calculate the height of the bottom of the canopy

    // new implementation for Fred
    m_fCanopyBottomHeight = m_fHeight - (oAllTrees.GetCrownDepthCoefficient(sSpecies) * 
    						java.lang.Math.pow(m_fHeight , oAllTrees.GetCrownDepthExponent(sSpecies)));
    
	// original implementation
//    m_fCanopyBottomHeight = m_fHeight -
//        (m_fHeight * oAllTrees.GetCanopyDepthCoefficient(sSpecies));

  }

}
